@@ -21,10 +21,10 @@
  * Modified by the GLib Team and others 1997-2000.  See the AUTHORS
  * file for a list of people on the GLib Team.  See the ChangeLog
  * files for a list of changes.  These files are distributed with
- * GLib at ftp://ftp.gtk.org/pub/gtk/. 
+ * GLib at ftp://ftp.gtk.org/pub/gtk/.
  */
 
-/* 
+/*
  * MT safe
  */
 
@@ -41,10 +41,18 @@
 #include <locale.h>
 #include <errno.h>
 
-#include "glib.h"
+#include "gmessages.h"
+
+#include "gbacktrace.h"
+#include "gconvert.h"
 #include "gdebug.h"
+#include "gmem.h"
 #include "gprintfint.h"
+#include "gtestutils.h"
+#include "gthread.h"
 #include "gthreadprivate.h"
+#include "gstrfuncs.h"
+#include "gstring.h"
 
 #ifdef G_OS_WIN32
 #include <process.h>		/* For getpid() */
@@ -55,6 +63,7 @@
 #  undef STRICT
 #endif
 
+
 /* --- structures --- */
 typedef struct _GLogDomain	GLogDomain;
 typedef struct _GLogHandler	GLogHandler;
